@@ -7,11 +7,11 @@
 #' @param coefs vector of regression coefficients.
 #' @param data data frame containing the covariates used to construct the linear predictors.
 #' @param ... further arguments passed to other methods.
-#' @return a vector containing the linear predictors
+#' @return a vector containing the linear predictors.
 #'
 #' @examples
-#' \donttest{
 #' library(rsurv)
+#' library(dplyr)
 #'
 #' n <- 100
 #' coefs <- c(1, 0.7, 2.3)
@@ -24,7 +24,6 @@
 #'     lp = lp(~age+sex, coefs)
 #'   )
 #' glimpse(simdata)
-#' }
 #'
 
 lp <- function(formula, coefs, data, ...){
@@ -33,7 +32,7 @@ lp <- function(formula, coefs, data, ...){
   }else{
     mf <- stats::model.frame(formula=formula, data=data)
   }
-  X <- stats::model.matrix(mf)
+  X <- stats::model.matrix(mf, ...)
   lp <- as.numeric(X%*%coefs)
   return(lp)
 }
